package com.tzld.crawler.etl.controller;

import com.alibaba.fastjson.JSONObject;
import com.aliyun.mq.http.MQClient;
import com.aliyun.mq.http.MQProducer;
import com.aliyun.mq.http.model.TopicMessage;
import com.tzld.crawler.etl.model.vo.CrawlerEtlParam;
import com.tzld.crawler.etl.service.EtlService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;

import java.util.stream.IntStream;

/**
 * @author ehlxr
 */
@RestController
@RequestMapping("/")
public class IndexController {
    private static final Logger LOGGER = LoggerFactory.getLogger(IndexController.class);
    @Autowired
    private EtlService etlService;

    @Value("${rocketmq.accessKey:}")
    private String accessKey;
    @Value("${rocketmq.secretKey:}")
    private String secretKey;
    @Value("${rocketmq.httpEndpoint:}")
    private String httpEndpoint;
    @Value("${rocketmq.instanceId:}")
    private String instanceId;
    @Value("${rocketmq.crawler.etl.topic:}")
    private String topic;
    @Value("${rocketmq.crawler.etl.groupid:}")
    private String groupId;

    /**
     * 探活
     *
     * @return
     */
    @GetMapping("/healthcheck")
    public String healthcheck() {
        LOGGER.info("I'm ok");
        return "ok";
    }

    public static void main(String[] args) {
        String s = "{\"user_id\": 6281907,\"out_user_id\": \"53322270\",\"platform\": \"xiaoniangao\",\"strategy\": \"author\",\"out_video_id\": \"5067863383\",\"video_title\": \"早上起床前念四句话，身体有可能变得更健康\uD83D\uDC8E\",\"cover_url\": \"https://cdn-xphoto2.xiaoniangao.cn/5067863386@690w_385h_0e_1pr%7C690x385-5rc_0r.jpg?OSSAccessKeyId=LTAI4G2W1FsgwzAWYpPoB3v6&Expires=1688140805&Signature=F%2BIn%2FdAfjM4UWnG%2F96qAUcHWhpI%3D\",\"video_url\": \"http://cdn-xalbum-baishan.xiaoniangao.cn/5067863383?Expires=1704038400&OSSAccessKeyId=LTAI5tB7cRkYiqHcTdkVprwb&Signature=kD2sBhazSa4L5q/XolJ8BkxW6SI%3D\",\"duration\": 40,\"publish_time\": \"2023-06-08 23:01:47\",\"play_cnt\": 602,\"like_cnt\": 0,\"share_cnt\": 0,\"collection_cnt\": 0,\"comment_cnt\": 0,\"crawler_rule\": {\"period\": {\"max\": 3,\"min\": 3},\"duration\": {\"max\": 999999999999999,\"min\": 40},\"play_cnt\": {\"max\": 999999999999999,\"min\": 500}},\"width\": 450,\"height\": 254}";
        System.out.println(JSONObject.parseObject(s, CrawlerEtlParam.class));
    }

    @PostMapping("/etl")
    public String deal(@RequestBody CrawlerEtlParam param) {
        etlService.deal(param);
        return "ok";
    }

    @RequestMapping("/sendMsg")
    public String sendMsg(@RequestParam(value = "size", required = false, defaultValue = "10000") int size) {
        MQClient mqClient = new MQClient(httpEndpoint, accessKey, secretKey);
        MQProducer producer = mqClient.getProducer(instanceId, topic);

        String msg = "{\"userId\":6282865,\"outUserId\":\"51101170\",\"platform\":\"douyin\",\"strategy\":\"search\",\"outVideoId\":\"ppp212122fdf22\",\"videoTitle\":\"早上起床前念四句话，身体有可能变得更健康\",\"coverUrl\":\"https://cdn-xphoto2.xiaoniangao.cn/5111511988@690w_385h_0e_1pr_0r.jpg\",\"videoUrl\":\"http://v9-xg-web-pc.ixigua.com/c8347a501c9f589ff862d459249aa1eb/635fff\",\"audioUrl\":\"http://cdn-xalbum-baishan.xiaoniangao.cn/5111511797?Expires=1704038400\"}";

        IntStream.range(0, size).parallel().forEach((i) -> {
            TopicMessage pubMsg = new TopicMessage(msg.getBytes());
            pubMsg.setMessageKey("test_" + i);
            TopicMessage pubResultMsg = producer.publishMessage(pubMsg);
            LOGGER.info("Send mq message: id={} success. Topic is: {}, msgId is: {}",
                    i, topic, pubResultMsg.getMessageId());
        });


        return "ok";
    }
}
